import _pluginCorejs2 from "babel-plugin-polyfill-corejs2";
import _pluginCorejs3 from "babel-plugin-polyfill-corejs3";
import _pluginRegenerator from "babel-plugin-polyfill-regenerator";
const pluginCorejs2 = _pluginCorejs2.default || _pluginCorejs2;
const pluginCorejs3 = _pluginCorejs3.default || _pluginCorejs3;
const pluginRegenerator = _pluginRegenerator.default || _pluginRegenerator;
const pluginsCompat = "#__secret_key__@babel/runtime__compatibility";
function createCorejsPlugin(plugin, options, regeneratorPlugin) {
  return (api, _, filename) => {
    return Object.assign({}, plugin(api, options, filename), {
      inherits: regeneratorPlugin
    });
  };
}
function createRegeneratorPlugin(options, useRuntimeRegenerator) {
  if (!useRuntimeRegenerator) return undefined;
  return (api, _, filename) => {
    return pluginRegenerator(api, options, filename);
  };
}
export function createBasePolyfillsPlugin({
  corejs,
  regenerator: useRuntimeRegenerator = true
}, runtimeVersion, absoluteImports) {
  let proposals = false;
  let rawVersion;
  if (typeof corejs === "object" && corejs !== null) {
    rawVersion = corejs.version;
    proposals = Boolean(corejs.proposals);
  } else {
    rawVersion = corejs;
  }
  const corejsVersion = rawVersion ? Number(rawVersion) : false;
  if (![false, 2, 3].includes(corejsVersion)) {
    throw new Error(`The \`core-js\` version must be false, 2 or 3, but got ${JSON.stringify(rawVersion)}.`);
  }
  if (proposals && (!corejsVersion || corejsVersion < 3)) {
    throw new Error("The 'proposals' option is only supported when using 'corejs: 3'");
  }
  if (typeof useRuntimeRegenerator !== "boolean") {
    throw new Error("The 'regenerator' option must be undefined, or a boolean.");
  }
  const polyfillOpts = {
    method: "usage-pure",
    absoluteImports,
    [pluginsCompat]: {
      useBabelRuntime: true,
      runtimeVersion,
      ext: ""
    }
  };
  return corejsVersion === 2 ? createCorejsPlugin(pluginCorejs2, polyfillOpts, createRegeneratorPlugin(polyfillOpts, useRuntimeRegenerator)) : corejsVersion === 3 ? createCorejsPlugin(pluginCorejs3, Object.assign({
    version: 3,
    proposals
  }, polyfillOpts), createRegeneratorPlugin(polyfillOpts, useRuntimeRegenerator)) : createRegeneratorPlugin(polyfillOpts, useRuntimeRegenerator);
}

//# sourceMappingURL=polyfills.js.map
